==> xarchiver-0.5.4.8.tar.gz: xarchiver-0.5.4.8/src/string_utils.h <==
/*
 *  Copyright (C) 2008 Giuseppe Torelli - <colossus73@gmail.com>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02111-1307, USA.
 */

#ifndef STRING_UTILS_H
#define STRING_UTILS_H

#include "config.h"
#include <stdlib.h>
#include <string.h>
#include <gtk/gtk.h>
#include "archive.h"

#ifndef HAVE_STRCASESTR
const char *strcasestr(const char *haystack, const char *needle);
#endif
#ifndef HAVE_MKDTEMP
char *mkdtemp (gchar *tmpl);
#endif
gchar *xa_escape_bad_chars ( gchar *string , gchar *pattern);
char *xa_escape_common_chars (const char *str, const char *meta_chars, const char  prefix, const char  postfix);
gchar *xa_remove_level_from_path (const gchar *path);
gboolean file_extension_is (const char *filename, const char *ext);
void xa_set_window_title ( GtkWidget *window , gchar *title);
gboolean match_patterns (char **patterns,const char *string,int flags);
gchar *xa_remove_path_from_archive_name(gchar *name);
void xa_cat_filenames (XArchive *,GSList *,GString *);
gchar *xa_escape_filename (gchar *filename,gchar *meta_chars);
GSList *xa_slist_copy(GSList *);
void xa_recurse_local_directory(gchar *,GSList **,gboolean,gint);
gchar *xa_strip_current_working_dir_from_path(gchar *,gchar *);
#endif

==> xarchiver_0.5.4.10.orig.tar.gz: xarchiver-0.5.4.10/src/string_utils.h <==
/*
 *  Copyright (C) 2008 Giuseppe Torelli - <colossus73@gmail.com>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02111-1307, USA.
 */

#ifndef XARCHIVER_STRING_UTILS_H
#define XARCHIVER_STRING_UTILS_H

#include "config.h"
#include <gtk/gtk.h>
#include "archive.h"

#define ESCAPES " \"'\\"

#ifndef HAVE_MKDTEMP
gchar *mkdtemp(gchar *);
#else
#include <stdlib.h>
#endif

#ifndef HAVE_STRCASESTR
const char *strcasestr(const char *haystack, const char *needle);
#else
#include <string.h>
#endif

gboolean match_patterns(char **, const char *, int);
gchar *xa_escape_bad_chars(const gchar *, const gchar *);
GSList *xa_collect_filenames(XArchive *, GSList *);
GString *xa_quote_filenames(GSList *, const gchar *, gboolean);
gchar *xa_quote_shell_command(const gchar *, gboolean);
void xa_recurse_local_directory(gchar *, GSList **, gboolean);
gchar *xa_remove_level_from_path(const gchar *);
void xa_set_window_title(GtkWidget *, gchar *);
GSList *xa_slist_copy(GSList *);

#endif
